package de.samdev.colorrunner.screens.gameScreen;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.InputMultiplexer;
import com.badlogic.gdx.Screen;
import com.badlogic.gdx.graphics.GL20;
import com.badlogic.gdx.input.GestureDetector;
import com.badlogic.gdx.scenes.scene2d.Stage;
import com.badlogic.gdx.utils.viewport.ExtendViewport;

import de.samdev.colorrunner.actors.CRPlayer;
import de.samdev.colorrunner.input.CRGameInputProcessor;
import de.samdev.colorrunner.input.GameInputListener;
import de.samdev.colorrunner.input.SwipeDirection;

public class GameScreen implements Screen, GameInputListener {
	private Stage stage;
	
	private CRPlayer player;
	
	public GameScreen() {
		stage = new Stage(new ExtendViewport(967, 544));
		
		player = new CRPlayer();
		stage.addActor(player);
	}

	@Override
	public void render(float delta) {
		Gdx.gl.glClear(GL20.GL_COLOR_BUFFER_BIT);
		
	    stage.act(delta);
		stage.draw();
		
//		stage.getViewport().getCamera().position.x = player.getX();
	}

	@Override
	public void resize(int width, int height) {
        Gdx.app.log("GameScreen", "resize called");	
	}

	@Override
	public void show() {
		CRGameInputProcessor ip = new CRGameInputProcessor(this);
		Gdx.input.setInputProcessor(new InputMultiplexer(stage, ip, new GestureDetector(ip)));
		
        Gdx.app.log("GameScreen", "show called");	
	}

	@Override
	public void hide() {
		Gdx.input.setInputProcessor(null);
		
        Gdx.app.log("GameScreen", "hide called");   
	}

	@Override
	public void pause() {
        Gdx.app.log("GameScreen", "pause called");
	}

	@Override
	public void resume() {
        Gdx.app.log("GameScreen", "resume called");     
	}

	@Override
	public void dispose() {
        Gdx.app.log("GameScreen", "dispose called");     
	}

	@Override
	public void doJump() {
        player.jump();
        
        Gdx.app.log("GameScreen", "[DO] Jump");     
	}

	@Override
	public void switchColor(SwipeDirection sd) {
		player.switchColorState(sd);
		
        Gdx.app.log("GameScreen", "[DO] Switch + " + sd.toString());    
	}

}
